from ArcUUID.ArcUUID import ArcUUID


class Ids:

    WAPO = ArcUUID.from_string("PW5TIZPZINHXBPNQTAJRSISO3E")
    DEMO1 = ArcUUID.from_string("2HDHHWH45JAHDFRWJKX2TJDVFA")
    DEMO2 = ArcUUID.from_string("P36DKL6XL5HKFEK33TSRHKDXRM")
    DEMO3 = ArcUUID.from_string("QFJBYOYVDZC35N2X33UBMMCUNI")

    def __init__(self):
        pass

